==> ejc-techmanagement-impl-3.0.0-20250403.014632-83-sources.jar: com/ejianc/business/techmanagement/bean/ConstructionSchemeEntity.java <==
package com.ejianc.business.techmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工方案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_techmanagement_construction_scheme")
public class ConstructionSchemeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父组织ID
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父组织编码
    @TableField(value="build_unit_id")
    private Long buildUnitId; // 二级单位ID
    @TableField(value="build_unit_name")
    private String buildUnitName; // 二级单位
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类型ID
    @TableField(value="engineering_type")
    private String engineeringType; // 工程类型
    @TableField(value="measure")
    private String measure; // 工程规模
    @TableField(value="scheme_id")
    private Long schemeId; // 方案ID
    @TableField(value="scheme_name")
    private String schemeName; // 方案名称
    @TableField(value="scheme_code")
    private String schemeCode; // 方案编码
    @TableField(value="scheme_code_num")
    private String schemeCodeNum; // 方案版本号
    @TableField(value="scheme_code_plan")
    private String schemeCodePlan; // 方案分类
    @TableField(value="scheme_parent_id")
    private String schemeParentId; // 方案上级ID
    @TableField(value="employee_id")
    private Long employeeId; // 经办人ID
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门ID
    @TableField(value="department_name")
    private String departmentName; // 经办部门
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="disclosure_id")
    private Long disclosureId; // 交底ID
    @TableField(value="disclosure_state")
    private Integer disclosureState; // 交底状态
    @TableField(value="disclosure_time")
    private Date disclosureTime; // 交底日期
    @TableField(value="disclosure_content")
    private String disclosureContent; // 交底内容及结果说明

    public String getSchemeCodeNum() {
        return schemeCodeNum;
    }

    public void setSchemeCodeNum(String schemeCodeNum) {
        this.schemeCodeNum = schemeCodeNum;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getBuildUnitId() {
        return buildUnitId;
    }

    public void setBuildUnitId(Long buildUnitId) {
        this.buildUnitId = buildUnitId;
    }
    public String getBuildUnitName() {
        return buildUnitName;
    }

    public void setBuildUnitName(String buildUnitName) {
        this.buildUnitName = buildUnitName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    public String getMeasure() {
        return measure;
    }

    public void setMeasure(String measure) {
        this.measure = measure;
    }
    public Long getSchemeId() {
        return schemeId;
    }

    public void setSchemeId(Long schemeId) {
        this.schemeId = schemeId;
    }
    public String getSchemeName() {
        return schemeName;
    }

    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    public String getSchemeCode() {
        return schemeCode;
    }

    public void setSchemeCode(String schemeCode) {
        this.schemeCode = schemeCode;
    }
    public String getSchemeCodePlan() {
        return schemeCodePlan;
    }

    public void setSchemeCodePlan(String schemeCodePlan) {
        this.schemeCodePlan = schemeCodePlan;
    }
    public String getSchemeParentId() {
        return schemeParentId;
    }

    public void setSchemeParentId(String schemeParentId) {
        this.schemeParentId = schemeParentId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }
    public Integer getDisclosureState() {
        return disclosureState;
    }

    public void setDisclosureState(Integer disclosureState) {
        this.disclosureState = disclosureState;
    }
    public Date getDisclosureTime() {
        return disclosureTime;
    }

    public void setDisclosureTime(Date disclosureTime) {
        this.disclosureTime = disclosureTime;
    }
    public String getDisclosureContent() {
        return disclosureContent;
    }

    public void setDisclosureContent(String disclosureContent) {
        this.disclosureContent = disclosureContent;
    }
    
}

==> ejc-techmanagement-impl-3.0.0-20250423.013417-103-sources.jar: com/ejianc/business/techmanagement/bean/ConstructionSchemeEntity.java <==
package com.ejianc.business.techmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工方案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_techmanagement_construction_scheme")
public class ConstructionSchemeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父组织ID
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父组织编码
    @TableField(value="build_unit_id")
    private Long buildUnitId; // 二级单位ID
    @TableField(value="build_unit_name")
    private String buildUnitName; // 二级单位
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类型ID
    @TableField(value="engineering_type")
    private String engineeringType; // 工程类型
    @TableField(value="measure")
    private String measure; // 工程规模
    @TableField(value="scheme_id")
    private Long schemeId; // 方案ID
    @TableField(value="scheme_name")
    private String schemeName; // 方案名称
    @TableField(value="scheme_code")
    private String schemeCode; // 方案编码
    @TableField(value="scheme_code_num")
    private String schemeCodeNum; // 方案版本号
    @TableField(value="scheme_code_plan")
    private String schemeCodePlan; // 方案分类
    @TableField(value="scheme_parent_id")
    private String schemeParentId; // 方案上级ID
    @TableField(value="employee_id")
    private Long employeeId; // 经办人ID
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门ID
    @TableField(value="department_name")
    private String departmentName; // 经办部门
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="disclosure_id")
    private Long disclosureId; // 交底ID
    @TableField(value="disclosure_state")
    private Integer disclosureState; // 交底状态
    @TableField(value="disclosure_time")
    private Date disclosureTime; // 交底日期
    @TableField(value="disclosure_content")
    private String disclosureContent; // 交底内容及结果说明
    @TableField(value="disclosure_type")
    private Integer disclosureType; // 交底单据类型 1：方案交底 2：质量技术交底 3：安全技术交底

    public Integer getDisclosureType() {
        return disclosureType;
    }

    public void setDisclosureType(Integer disclosureType) {
        this.disclosureType = disclosureType;
    }
    public String getSchemeCodeNum() {
        return schemeCodeNum;
    }

    public void setSchemeCodeNum(String schemeCodeNum) {
        this.schemeCodeNum = schemeCodeNum;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getBuildUnitId() {
        return buildUnitId;
    }

    public void setBuildUnitId(Long buildUnitId) {
        this.buildUnitId = buildUnitId;
    }
    public String getBuildUnitName() {
        return buildUnitName;
    }

    public void setBuildUnitName(String buildUnitName) {
        this.buildUnitName = buildUnitName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    public String getMeasure() {
        return measure;
    }

    public void setMeasure(String measure) {
        this.measure = measure;
    }
    public Long getSchemeId() {
        return schemeId;
    }

    public void setSchemeId(Long schemeId) {
        this.schemeId = schemeId;
    }
    public String getSchemeName() {
        return schemeName;
    }

    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    public String getSchemeCode() {
        return schemeCode;
    }

    public void setSchemeCode(String schemeCode) {
        this.schemeCode = schemeCode;
    }
    public String getSchemeCodePlan() {
        return schemeCodePlan;
    }

    public void setSchemeCodePlan(String schemeCodePlan) {
        this.schemeCodePlan = schemeCodePlan;
    }
    public String getSchemeParentId() {
        return schemeParentId;
    }

    public void setSchemeParentId(String schemeParentId) {
        this.schemeParentId = schemeParentId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }
    public Integer getDisclosureState() {
        return disclosureState;
    }

    public void setDisclosureState(Integer disclosureState) {
        this.disclosureState = disclosureState;
    }
    public Date getDisclosureTime() {
        return disclosureTime;
    }

    public void setDisclosureTime(Date disclosureTime) {
        this.disclosureTime = disclosureTime;
    }
    public String getDisclosureContent() {
        return disclosureContent;
    }

    public void setDisclosureContent(String disclosureContent) {
        this.disclosureContent = disclosureContent;
    }
    
}
